summary refs log tree commit diff stats
diff options
context:
space:
mode:
authorAndinus <andinus@nand.sh>2020-04-15 19:26:10 +0530
committerAndinus <andinus@nand.sh>2020-04-15 19:26:10 +0530
commitbc9703246e571c39f9cdb2739b7a4b54ebf4bad2 (patch)
treeb28226278e17447ea90b79f8d9af0485d1970aa1
parent6e5a88bc7749b3fe4d9419b95a2ba2b596e3f837 (diff)
downloadlynx-bc9703246e571c39f9cdb2739b7a4b54ebf4bad2.tar.gz
Add Unveil & UnveilStrict func to unveil_other.go
-rw-r--r--unveil_other.go18
1 files changed, 16 insertions, 2 deletions
diff --git a/unveil_other.go b/unveil_other.go
index a0273c9..1131c31 100644
--- a/unveil_other.go
+++ b/unveil_other.go
@@ -2,14 +2,28 @@
 
 package lynx
 
-// UnveilPath takes a path, permission & unveils it, it does nothing
+// Unveil takes a path, permission & unveils it, it does nothing
 // on non OpenBSD systems.
+func Unveil(_ string, _ string) error {
+	return nil
+}
+
+// UnveilPath takes a path, permission & unveils it, it does nothing
+// on non OpenBSD systems. Unveil should be used instead of
+// UnveilPath.
 func UnveilPath(_ string, _ string) error {
 	return nil
 }
 
 // UnveilPathStrict is just a wrapper around unix.Unveil. It does
 // nothing on non OpenBSD systems.
+func UnveilStrict(_ string, _ string) error {
+	return nil
+}
+
+// UnveilPathStrict is just a wrapper around unix.Unveil. It does
+// nothing on non OpenBSD systems. UnveilStrict should be used instead
+// of UnveilPathStrict.
 func UnveilPathStrict(_ string, _ string) error {
 	return nil
 }
@@ -2,14 +2,28 @@
 }
 
-// UnveilPathStrict is just a wrapper around unix.Unveil. It does
+// UnveilStrict is just a wrapper around unix.Unveil. It does
 // nothing on non OpenBSD systems.